@@ -292,7 +292,7 @@ sub LoadByName {
 
     my $CFs = RT::CustomFields->new($self->CurrentUser);
 
-    $CFs->Limit( FIELD => 'Name', VALUE => $args{'Name'} );
+    $CFs->Limit( FIELD => 'Name', VALUE => $args{'Name'}, CASESENSITIVE => 0);
     # Don't limit to queue if queue is 0.  Trying to do so breaks
     # RT::Group type CFs.
     if (defined $args{'Queue'}) {
